@@ -1,25 +1,7 @@
 package Module::Use::Debug;
 
-use strict;
-use vars qw($VERSION);
+our $VERSION = 0.01;
 
-$VERSION = 0.04;
-
-
-package Module::Use;
-
-sub log {
-    my($self) = shift;
-
-    # dump to STDERR...
-    print STDERR "Modules used:\n  ", join("\n  ", sort @_), "\n";
-}
-
-sub _query_modules { };
-
-1;
-
-__END__
 
 =head1 NAME
 
@@ -43,10 +25,25 @@ L<Module::Use>.
 
 =head1 AUTHOR
 
-James G. Smith <jsmith@cpan.org>
+James G. Smith <jgsmith@jamesmith.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2002 Texas A&M University.  All Rights Reserved.
+Copyright (C) 2001 James G. Smith
 
 Released under the same license as Perl itself.
+
+=cut
+
+
+
+package Module::Use;
+
+sub log {
+    my($self) = shift;
+
+    # dump to STDERR...
+    print STDERR "Modules used:\n  ", join("\n  ", @_), "\n";
+}
+
+1;
